@@ -1,4 +1,4 @@
-package Email::Sender::Failure 2.500;
+package Email::Sender::Failure 2.600;
 # ABSTRACT: a report of failure from an email sending transport
 
 use Moo;
@@ -96,7 +96,7 @@ Email::Sender::Failure - a report of failure from an email sending transport
 
 =head1 VERSION
 
-version 2.500
+version 2.600
 
 =head1 PERL VERSION
 
@@ -150,11 +150,11 @@ be used as the C<message> of the new failure.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
