@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-package Email::Sender::Manual::QuickStart 1.500;
+package Email::Sender::Manual::QuickStart 2.600;
 # ABSTRACT: how to start using Email::Sender right now
 
 #pod =head1 QUICK START
@@ -41,9 +41,9 @@ package Email::Sender::Manual::QuickStart 1.500;
 #pod
 #pod We didn't have to tell Email::Sender::Simple where to send the message.  If you
 #pod don't specify recipients, it will use all the email addresses it can find in
-#pod the F<To> and F<Cc> headers by default.  It will use L<Email::Address> to parse
-#pod those fields.  Similarly, if no sender is specified, it will use the first
-#pod address found in the F<From> header.
+#pod the F<To> and F<Cc> headers by default.  It will use L<Email::Address::XS> to
+#pod parse those fields.  Similarly, if no sender is specified, it will use the
+#pod first address found in the F<From> header.
 #pod
 #pod In most email transmission systems, though, the headers are not by necessity
 #pod tied to the addresses used as the sender and recipients.  For example, your
@@ -251,12 +251,12 @@ Email::Sender::Manual::QuickStart - how to start using Email::Sender right now
 
 =head1 VERSION
 
-version 1.500
+version 2.600
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has a long-term perl support period.  That means it will not
-require a version of perl released fewer than five years ago.
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -301,9 +301,9 @@ This is exactly the same as saying:
 
 We didn't have to tell Email::Sender::Simple where to send the message.  If you
 don't specify recipients, it will use all the email addresses it can find in
-the F<To> and F<Cc> headers by default.  It will use L<Email::Address> to parse
-those fields.  Similarly, if no sender is specified, it will use the first
-address found in the F<From> header.
+the F<To> and F<Cc> headers by default.  It will use L<Email::Address::XS> to
+parse those fields.  Similarly, if no sender is specified, it will use the
+first address found in the F<From> header.
 
 In most email transmission systems, though, the headers are not by necessity
 tied to the addresses used as the sender and recipients.  For example, your
@@ -497,11 +497,11 @@ and the various Email::Sender::Transport classes.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
