@@ -1,4 +1,4 @@
-package Email::Sender::Transport 1.500;
+package Email::Sender::Transport 2.600;
 # ABSTRACT: a role for email transports
 
 use Moo::Role;
@@ -52,7 +52,7 @@ Email::Sender::Transport - a role for email transports
 
 =head1 VERSION
 
-version 1.500
+version 2.600
 
 =head1 DESCRIPTION
 
@@ -62,10 +62,10 @@ L<Email::Sender::Role::CommonSending>, which it includes. The important
 difference is that Transports are often intended to be used by
 L<Email::Sender::Simple>, and they provide two methods related to that purpose.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has a long-term perl support period.  That means it will not
-require a version of perl released fewer than five years ago.
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -88,11 +88,11 @@ all times.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
