@@ -1,4 +1,4 @@
-package Email::Sender::Transport::DevNull 1.500;
+package Email::Sender::Transport::DevNull 2.600;
 # ABSTRACT: happily throw away your mail
 
 use Moo;
@@ -28,17 +28,17 @@ Email::Sender::Transport::DevNull - happily throw away your mail
 
 =head1 VERSION
 
-version 1.500
+version 2.600
 
 =head1 DESCRIPTION
 
 This class implements L<Email::Sender::Transport>.  Any mail sent through a
 DevNull transport will be silently discarded.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has a long-term perl support period.  That means it will not
-require a version of perl released fewer than five years ago.
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -47,11 +47,11 @@ the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
