@@ -1,4 +1,4 @@
-package Email::Sender::Transport::Wrapper 1.500;
+package Email::Sender::Transport::Wrapper 2.600;
 # ABSTRACT: a mailer to wrap a mailer for mailing mail
 
 use Moo;
@@ -68,7 +68,7 @@ Email::Sender::Transport::Wrapper - a mailer to wrap a mailer for mailing mail
 
 =head1 VERSION
 
-version 1.500
+version 2.600
 
 =head1 DESCRIPTION
 
@@ -76,10 +76,10 @@ Email::Sender::Transport::Wrapper wraps a transport, provided as the
 C<transport> argument to the constructor.  It is provided as a simple way to
 use method modifiers to create wrapping classes.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has a long-term perl support period.  That means it will not
-require a version of perl released fewer than five years ago.
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -88,11 +88,11 @@ the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
